@@ -1,7 +1,7 @@
 from kindtool import cli, __app_name__
 
 def main():
-    cli.app(prog_name=__app_name__)
+    cli.main()
 
 if __name__ == "__main__":
     main()
\ No newline at end of file
